@@ -4,7 +4,7 @@ import weakref
 from abc import ABCMeta
 from copy import deepcopy
 from functools import partial
-from typing import overload, TypeVar, Generic, List, Generator, Union
+from typing import overload, TypeVar, Generic, List, Generator, Union, Optional, Any, get_args
 
 import numpy as np
 
@@ -21,7 +21,7 @@ class HookFunction:
     You should not instantiate it yourself.
     """
 
-    def __init__(self, func, hook, tryfirst=False, trylast=False):
+    def __init__(self, func, hook, tryfirst=False, trylast=False, wrapper=False):
         """
         :param func: the function
         :param hook: the associated hook
@@ -46,6 +46,9 @@ class HookFunction:
         self.cycle = False
         """Cycle detection."""
 
+        self.wrapper = wrapper
+        """Whether the hook function is a wrapper."""
+
         self._tryfirst = tryfirst
         self._trylast = trylast
 
@@ -65,9 +68,18 @@ class HookFunction:
         extra_args = self._determine_extra_args()
         self.cycle = True
         try:
-            result = self.function(instance, **extra_args)
+            if self.wrapper:
+                gen = self.function(instance, **extra_args)
+                next(gen)
+                gen.send(self.hook.get_result(instance))
+                raise SyntaxError("Wrapper function must only contain one yield expression.")
+            else:
+                result = self.function(instance, **extra_args)
+        except StopIteration as e:
+            result = e.value
         finally:
             self.cycle = False
+
         return result
 
     def __repr__(self):
@@ -110,6 +122,12 @@ class Hook(Generic[T]):
 
         self._functions: List[HookFunction] = []
 
+        self._wrappers: List[HookFunction] = []
+        self._first_wrappers: List[HookFunction] = []
+        self._last_wrappers: List[HookFunction] = []
+
+        self.__orig_class__ = None
+
     def __set_name__(self, owner, name):
         self.name = name
         self.owner = owner
@@ -140,6 +158,7 @@ class Hook(Generic[T]):
         if self.owner != owner:
             # create distinct instance on subclass
             hook = Hook()
+            hook.__orig_class__ = self.__orig_class__
             setattr(owner, self.name, hook)
             return hook.__get__(instance, owner)
 
@@ -151,6 +170,18 @@ class Hook(Generic[T]):
         # try to get value explicitly set by user
         result = instance.__dict__.get(self.name, None)
         if result is not None:
+            if callable(result):
+                if len(inspect.signature(result).parameters) == 0:
+                    result = result()
+                else:
+                    result = result(instance)
+
+                self.owner.logger.debug(
+                    f"Hook %s.%s on %s: resolved with explicit function result value %s.",
+                    self.owner.__qualname__, self.name, instance, result
+                )
+                return result
+
             self.owner.logger.debug(
                 f"Hook %s.%s on %s: resolved with explicit value %s.",
                 self.owner.__qualname__, self.name, instance, result
@@ -200,6 +231,17 @@ class Hook(Generic[T]):
         """
         instance.__dict__.pop(self.name, None)
 
+    @property
+    def type(self):
+        """
+        Returns the given generic attribute (the data type of the hook).
+        :raises TypeError: if the instance was not created using a generic parameter (so ``__orig_class__`` was not set)
+        """
+        if self.__orig_class__ is None:
+            raise TypeError("This instance was not instantiated using a generic type parameter.")
+        args = get_args(self.__orig_class__)
+        return args[0]
+
     def _yield_functions_from(self, attr: str):
         for s in self.owner.__mro__:
             h = getattr(s, self.name, None)
@@ -212,6 +254,9 @@ class Hook(Generic[T]):
         """
         Generator listing functions stored in this instance and equally named instances in superclasses of its owner.
         """
+        yield from self._yield_functions_from("_first_wrappers")
+        yield from self._yield_functions_from("_wrappers")
+        yield from self._yield_functions_from("_last_wrappers")
 
         yield from self._yield_functions_from("_first_functions")
         yield from self._yield_functions_from("_functions")
@@ -242,7 +287,7 @@ class Hook(Generic[T]):
                 self.owner.__qualname__, self.name, instance, f.qualname
             )
 
-    def add_function(self, func, tryfirst=False, trylast=False):
+    def add_function(self, func, tryfirst=False, trylast=False, wrapper=False):
         """
         Add the given function to the internal function store.
 
@@ -251,21 +296,29 @@ class Hook(Generic[T]):
         if isinstance(func, HookFunction):
             func = func.function
 
-        hf = HookFunction(func, self, trylast=trylast, tryfirst=tryfirst)
+        hf = HookFunction(func, self, trylast=trylast, tryfirst=tryfirst, wrapper=wrapper)
 
-        if tryfirst:
-            self._first_functions.append(hf)
-        elif trylast:
-            self._last_functions.append(hf)
+        if wrapper:
+            if tryfirst:
+                self._first_wrappers.append(hf)
+            elif trylast:
+                self._last_wrappers.append(hf)
+            else:
+                self._wrappers.append(hf)
         else:
-            self._functions.append(hf)
+            if tryfirst:
+                self._first_functions.append(hf)
+            elif trylast:
+                self._last_functions.append(hf)
+            else:
+                self._functions.append(hf)
 
         return hf
 
-    def __call__(self, func=None, tryfirst=False, trylast=False):
+    def __call__(self, func=None, tryfirst=False, trylast=False, wrapper=False):
         if func is None:
-            return partial(self.add_function, tryfirst=tryfirst, trylast=trylast)
-        return self.add_function(func, tryfirst=tryfirst, trylast=trylast)
+            return partial(self.add_function, tryfirst=tryfirst, trylast=trylast, wrapper=wrapper)
+        return self.add_function(func, tryfirst=tryfirst, trylast=trylast, wrapper=wrapper)
 
     def remove_function(self, func: HookFunction):
         """
@@ -273,7 +326,18 @@ class Hook(Generic[T]):
 
         :return: the underlying function object
         """
-        self._functions.remove(func)
+        for store in [
+            self._functions,
+            self._last_functions,
+            self._first_functions,
+            self._wrappers,
+            self._last_wrappers,
+            self._first_wrappers,
+        ]:
+            try:
+                store.remove(func)
+            except ValueError:
+                continue
         return func.function
 
     def __repr__(self):
@@ -369,6 +433,13 @@ class HookHost(ReprMixin, LogMixin, metaclass=_HookHostMeta):
             if not n.startswith("_") and not isinstance(v, weakref.ref)
         }
 
+    def root_hook_fallback(self, hook: Hook) -> Optional[Any]:
+        """
+        May return a fallback value for getting of root hooks.
+        The default implementation returns None, may be overridden in subclasses.
+        """
+        return None
+
     def evaluate_and_set_hooks(self):
         """Evaluate functions of root hooks and set the results explicitly as attributes."""
 
@@ -379,13 +450,16 @@ class HookHost(ReprMixin, LogMixin, metaclass=_HookHostMeta):
                     result = h.get_result(self)
 
                     if result is None:
-                        continue
+                        result = self.root_hook_fallback(h)
+
+                    if result is None:
+                        raise AttributeError(f"Call for root hook '{h.name}' on '{self}' resulted in None.")
 
                     setattr(self, h.name, result)
 
                     try:
                         arr = np.array(result)
-                        yield from arr[np.isfinite(arr)].flat
+                        yield from arr[np.isfinite(arr) | np.isinf(arr) | np.isnan(arr)].flat
                     except TypeError:  # yield only numeric values
                         continue
 
