@@ -72,12 +72,14 @@ class ReprMixin(ABC):
                 plt.close(plot)
                 svg = sio.getvalue()
 
-                svg = re.sub(r'height="[\d.\w]*?"', 'height="100%"', svg)
-                svg = re.sub(r'width="[\d.\w]*?"', 'width="100%"', svg)
+                return (
+                        "<table>"
+                        + "<tr><td style='text-align: center'>" + svg + "</td></tr>"
+                        + "<tr><td style='text-align: left'>" + table + "</td></tr>"
+                        + "</table>"
+                )
 
-                return "<div>" + svg + table + "</div>"
-
-        except (NotImplementedError, ImportError, AttributeError):
+        except (NotImplementedError, ImportError, AttributeError, TypeError):
             return table
 
     def __rich_repr__(self):
