@@ -1,7 +1,7 @@
 import numpy as np
 
 from pyroll.core.repr import ReprMixin
-from shapely import Polygon, LineString
+from shapely import Polygon, LineString, MultiPolygon, MultiLineString
 
 
 # noinspection PyAbstractClass
@@ -31,16 +31,17 @@ class PatchedPolygon(Polygon):
         }
 
 
-Polygon.height = PatchedPolygon.height
-Polygon.width = PatchedPolygon.width
-Polygon.perimeter = PatchedPolygon.perimeter
-Polygon.__attrs__ = PatchedPolygon.__attrs__
-Polygon.__str__ = ReprMixin.__str__
-Polygon.__repr__ = ReprMixin.__repr__
-# noinspection PyProtectedMember
-Polygon._repr_html_ = ReprMixin._repr_html_
-# noinspection PyProtectedMember
-Polygon._repr_pretty_ = ReprMixin._repr_pretty_
+for cls in [Polygon, MultiPolygon]:
+    cls.height = PatchedPolygon.height
+    cls.width = PatchedPolygon.width
+    cls.perimeter = PatchedPolygon.perimeter
+    cls.__attrs__ = PatchedPolygon.__attrs__
+    cls.__str__ = ReprMixin.__str__
+    cls.__repr__ = ReprMixin.__repr__
+    # noinspection PyProtectedMember
+    cls._repr_html_ = ReprMixin._repr_html_
+    # noinspection PyProtectedMember
+    cls._repr_pretty_ = ReprMixin._repr_pretty_
 
 _RECTANGLE_CORNERS = np.asarray(
     [
@@ -75,7 +76,7 @@ def rectangle(width: float, height: float):
 
 class PatchedLineString(LineString):
     @property
-    def depth(self) -> float:
+    def height(self) -> float:
         """Computes the height of the bounding box."""
         return self.bounds[3] - self.bounds[1]
 
@@ -88,17 +89,18 @@ class PatchedLineString(LineString):
     def __attrs__(self):
         return {
             "width": self.width,
-            "depth": self.depth,
+            "height": self.height,
             "length": self.length,
         }
 
 
-LineString.depth = PatchedLineString.depth
-LineString.width = PatchedLineString.width
-LineString.__attrs__ = PatchedLineString.__attrs__
-LineString.__str__ = ReprMixin.__str__
-LineString.__repr__ = ReprMixin.__repr__
-# noinspection PyProtectedMember
-LineString._repr_html_ = ReprMixin._repr_html_
-# noinspection PyProtectedMember
-LineString._repr_pretty_ = ReprMixin._repr_pretty_
+for cls in [LineString, MultiLineString]:
+    cls.height = PatchedLineString.height
+    cls.width = PatchedLineString.width
+    cls.__attrs__ = PatchedLineString.__attrs__
+    cls.__str__ = ReprMixin.__str__
+    cls.__repr__ = ReprMixin.__repr__
+    # noinspection PyProtectedMember
+    cls._repr_html_ = ReprMixin._repr_html_
+    # noinspection PyProtectedMember
+    cls._repr_pretty_ = ReprMixin._repr_pretty_
